@@ -243,6 +243,25 @@ findTakeOff <- function(forceConcentric, maxSpeedTInConcentric)
 
 	return(takeoff)
 }
+
+#find the absolute distance reached on ec curve
+findDistanceAbsoluteEC <- function(position)
+{
+	#	-
+	#	 \       /
+	#	  \     /
+	#	   \   /
+	#	    \_/
+	#	A    B   C
+
+	#1st, find B value
+	minB = min(position)
+	minBms = min(which(position == minB))
+	maxA = max(position[1:minBms])
+	maxC = max(position[minBms:length(position)])
+
+	return ( (maxA - minB) + (maxC - minB) )
+}
 	
 
 getSpeedSafe <- function(displacement, smoothing) {
@@ -1081,6 +1100,107 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 	return(displacementPerson)
 }
 
+#used when user captures without string fully extended
+#signal is the information coming from the encoder, graph is to debug
+#see codeExplained/image detect-and-fix-inertial-string-not-fully-extended.png
+fixInertialSignalIfNotFullyExtended <- function(signal, saveFile, specialDataFile, graph)
+{
+	write("at fixInertialSignalIfNotFullyExtended", stderr())
+	angle <- cumsum(signal) #360 degrees every 200 ticks
+
+	maximums <- extrema(angle)$maxindex[,1]
+	minimums <- extrema(angle)$minindex[,1]
+	maximumsCopy <- maximums #store this value
+	minimumsCopy <- minimums #store this value
+		
+	#if we have more than 2 max & mins, remove the first and last value
+	if(length(maximums) > 2 & length(minimums) > 2)
+	{
+		#if there's any max extrema value negative (remove it), same for positive min values
+		maximums.temp = NULL
+		minimums.temp = NULL
+		for( i in maximums )
+			if(angle[i] > 0)
+				maximums.temp <- c(maximums.temp, i)
+		for( i in minimums )
+			if(angle[i] < 0)
+				minimums.temp <- c(minimums.temp, i)
+		
+		maximums <- maximums.temp
+		minimums <- minimums.temp
+
+		#remove the first value of the maximums OR minimums (just the first one of both)
+		if(maximums[1] < minimums[1])
+			maximums <- maximums[-1]
+		else
+			minimums <- minimums[-1]
+
+		#remove the last value of the maximums OR minimums (just the last one of both)
+		if(maximums[length(maximums)] > minimums[length(minimums)])
+			maximums <- maximums[-length(maximums)]
+		else
+			minimums <- minimums[-length(minimums)]
+	}
+
+	#return if no data
+	if(length(maximums) < 1 | length(minimums) < 1)
+		return(signal)
+
+	#ensure both maximums and minimums have same length
+	while(length(maximums) != length(minimums))
+	{
+		if(length(maximums) > length(minimums))
+			maximums <- maximums[-length(maximums)]
+		else if(length(maximums) < length(minimums))
+			minimums <- minimums[-length(minimums)]
+	}
+
+	meanByExtrema <- mean(c(angle[maximums], angle[minimums]))
+	angleCorrected <- angle - meanByExtrema
+
+	#remove the initial part of the signal. Remove from ms 1 to when angleCorrected crosses 0
+	angleCorrectedCrossZero = extrema(angleCorrected)$cross[1,1]
+
+	if(graph) {
+		par(mfrow=c(1,2))
+
+		#1st graph (left)
+		plot(angle, type="l", lty=2, xlab="time", ylab="Angle", main="String NOT fully extended", 
+		     ylim=c(min(c(angle[minimums], -angle[maximums])) - abs(meanByExtrema), max(c(angle[maximums], -angle[minimums])) + abs(meanByExtrema)))
+		lines(abs(angle)*-1, lwd=2)
+		points(maximumsCopy, angle[maximumsCopy], col="black", cex=1)
+		points(minimumsCopy, angle[minimumsCopy], col="black", cex=1)
+		points(maximums, angle[maximums], col="green", cex=3)
+		points(minimums, angle[minimums], col="green", cex=3)
+		abline(h = meanByExtrema, col="red")
+		text(x = 0, y = meanByExtrema, labels = round(meanByExtrema,2), adj=0)
+
+		#2nd graph (right)
+		plot(angleCorrected, type="l", lty=2, xlab="time", ylab="angle", main="Corrected set", 
+		     ylim=c(min(c(angle[minimums], -angle[maximums])) - 2*abs(meanByExtrema), max(c(angle[maximums], -angle[minimums]))))
+		lines(abs(angleCorrected)*-1, lwd=2)
+		abline(v=c(angleCorrectedCrossZero, length(angleCorrected)), col="green")
+		mtext("Start", at=angleCorrectedCrossZero, side=3, col="green")
+		mtext("EnfixInertialSignalIfNotFullyExtendedd", at=length(angleCorrected), side=3, col="green")
+
+		par(mfrow=c(1,1))
+	}
+
+	#define new signal only if the error in extended string is more than 5 revolutions
+	if(abs(meanByExtrema) > 1000) {
+		#write(signal, file="/tmp/old.txt", ncolumns=length(signal), sep=", ")
+		signal <- signal[angleCorrectedCrossZero:length(signal)]
+
+		write("SIGNAL CORRECTED", specialDataFile)
+		
+		#write to file and return displacement to be used
+		write(signal, file=saveFile, ncolumns=length(signal), sep=", ")
+	}
+	
+	return(signal)
+}
+
+
 
 #Read a double vector indicating the initial diameter of every loop of the rope
 #plus the final diameter of the last loop and returns a dataframe with the radius
