@@ -339,6 +339,7 @@ public abstract class ChronopicAuto
 		return true;
 	}
 	private void close(SerialPort sp) {
+		LogB.Information("closing port... ");
 		sp.Close();
 	}	
 
@@ -540,14 +541,18 @@ public class ChronopicStartReactionTimeAnimation : ChronopicAuto
 				b = 0x6c;
 			else if(CharToSend == "f")
 				b = 0x66;
-			else if(CharToSend == "d")
-				b = 0x64;
-			else if(CharToSend == "D")
-				b = 0x44;
-			else if(CharToSend == "i")
-				b = 0x69;
-			else if(CharToSend == "I")
-				b = 0x49;
+			else if(CharToSend == "r")
+				b = 0x72;
+			else if(CharToSend == "s")
+				b = 0x73;
+			else if(CharToSend == "t")
+				b = 0x74;
+			else if(CharToSend == "T") //green and buzzer
+				b = 0x54;
+			else if(CharToSend == "y") //red green
+				b = 0x76;
+			else if(CharToSend == "Z")
+				b = 0x5A;
 			else
 				return "ERROR";
 
