@@ -164,8 +164,14 @@ public class Constants
 	public const string Name = "name";
 	public const string Height = "height";
 	public const string Weight = "weight";
+	
+	//simulated tests and SIMULATED session
+	public const string SessionSimulatedName = "SIMULATED"; //Do NOT translate this 
+	public static string SessionProtected = Catalog.GetString("Sorry, this session cannot be modified."); //SIMULATED session
+	public static string SimulatedTestsNotAllowed = Catalog.GetString("Chronopic is disconnected.") + "\n\n" + 
+		string.Format(Catalog.GetString("If you want to simulate tests, use {0} session."), "SIMULATED");
 
-	//server	
+	//server
 	public const string ServerPingTable = "SPing"; 
 	public const string ServerEvaluatorTable = "SEvaluator"; 
 	public const string IPUnknown = "Unknown"; 
@@ -818,7 +824,7 @@ public class Constants
 	public enum Encoder1RMMethod { NONWEIGHTED, WEIGHTED, WEIGHTED2, WEIGHTED3 }
 	public enum ContextMenu { NONE, EDITDELETE, DELETE }
 	
-	public enum EncoderAutoSaveCurve { ALL, NONE, BEST }
+	public enum EncoderAutoSaveCurve { ALL, NONE, BEST, FROM4TOPENULTIMATE }
 
 	public enum DoubleContact {
 		NONE, FIRST, AVERAGE, LAST
