@@ -307,7 +307,13 @@ public class EncoderRProcCapture : EncoderRProc
 	//here curve is sent compressed (string. eg: "0*5 1 0 -1*3 2")
 	public void SendCurve(string curveCompressed)
 	{
-		LogB.Information("curveSend [displacement array]",curveCompressed);
+		/*
+		 * curveCompressed print has made crash Chronojump once.
+		 * Seems to be a problem with multithreading and Console.SetOut, see logB Commit (added a try/catch there)
+		 * on 2016 August 5 (1.6.2) should be fixed with LogSync class, but for now better leave this commented until more tests are done
+		 */
+		//LogB.Information("curveSend [displacement array]",curveCompressed);
+
 		p.StandardInput.WriteLine(curveCompressed); 	//this will send some lines because compressed data comes with '\n's
 		p.StandardInput.WriteLine("E");		//this will mean the 'E'nd of the curve. Then data can be uncompressed on R
 	}	
@@ -432,7 +438,7 @@ public class EncoderRProcAnalyze : EncoderRProc
 		if(es.Ep.Analysis == "exportCSV")
 			Util.FileDelete(UtilEncoder.GetEncoderStatusTempBaseFileName() + "6.txt");
 
-		//delete 1RM data if exists
+		//delete SpecialData if exists
 		string specialData = UtilEncoder.GetEncoderSpecialDataTempFileName();
 		if (File.Exists(specialData))
 			File.Delete(specialData);
@@ -506,7 +512,7 @@ public class EncoderRProcAnalyze : EncoderRProc
 		if(es.Ep.Analysis == "exportCSV")
 			Util.FileDelete(UtilEncoder.GetEncoderStatusTempBaseFileName() + "6.txt");
 		
-		//delete 1RM data if exists
+		//delete SpecialData if exists
 		string specialData = UtilEncoder.GetEncoderSpecialDataTempFileName();
 		if (File.Exists(specialData))
 			File.Delete(specialData);
