@@ -168,7 +168,7 @@ public partial class ChronoJumpWindow
 	};
 	
 
-	ExecutingGraphData event_execute_initializeVariables (
+	private void event_execute_initializeVariables (
 			bool simulated,
 			int personID,
 			string personName,
@@ -246,7 +246,9 @@ public partial class ChronoJumpWindow
 		layoutBig = new Pango.Layout (event_execute_drawingarea.PangoContext);
 		layoutBig.FontDescription = Pango.FontDescription.FromString ("Courier 14");
 		//layoutBig.Alignment = Pango.Alignment.Center; //doesn't work, see GetPixelSize below
-	
+	}
+	private ExecutingGraphData event_execute_prepareForTest () 
+	{
 		eventHasEnded = false;
 
 		checkbutton_video.Sensitive = false;
@@ -495,7 +497,7 @@ public partial class ChronoJumpWindow
 	
 
 	// simple and DJ jump	
-	public void PrepareJumpSimpleGraph(PrepareEventGraphJumpSimple eventGraph)
+	public void PrepareJumpSimpleGraph(PrepareEventGraphJumpSimple eventGraph, bool animate)
 	{
 		//check graph properties window is not null (propably user has closed it with the DeleteEvent
 		//then create it, but not show it
@@ -511,6 +513,8 @@ public partial class ChronoJumpWindow
 		//if max value of graph is automatic
 		if(eventGraphConfigureWin.Max == -1) {
 			maxValue = eventGraph.sessionMAXAtSQL;
+			if(eventGraph.personMAXAtSQLAllSessions > maxValue)
+				maxValue = eventGraph.personMAXAtSQLAllSessions;
 
 			//fix if there's a max tc that's higher than max tv
 			foreach(string myStr in eventGraph.jumpsAtSQL) {
@@ -546,13 +550,41 @@ public partial class ChronoJumpWindow
 		
 		//paint graph
 		paintJumpSimple (event_execute_drawingarea, eventGraph, 
-			       	maxValue, minValue, topMargin, bottomMargin);
+			       	maxValue, minValue, topMargin, bottomMargin, animate);
 
 		// -- refresh
 		event_execute_drawingarea.QueueDraw();
 		
 	}
 	
+	private void on_button_person_max_all_sessions_info_clicked(object o, EventArgs args) 
+	{
+		string [] str;
+		string testName;
+		if(radio_mode_jumps_small.Active) {
+			str = SqliteJump.SelectTestMaxStuff(currentPerson.UniqueID, currentJumpType); 
+			testName = currentJumpType.Name;
+		}
+		else if(radio_mode_runs_small.Active) {
+			str = SqliteRun.SelectTestMaxStuff(currentPerson.UniqueID, currentRunType); 
+			testName = currentRunType.Name;
+		} else
+			return;
+
+		if(str[2] == "" || str[2] == "0")
+			new DialogMessage(Constants.MessageTypes.WARNING, Catalog.GetString("Missing data."));
+		else {
+			string message = string.Format(Catalog.GetString("Best {0} test of person {1} is {2}\nDone at session {3} ({4})"),
+					testName, currentPerson.Name, 
+					Util.TrimDecimals(Util.ChangeDecimalSeparator(str[2]), 3), 
+					str[1], str[0]);
+			if(str[3] == "-1")
+				message += "\n" + Catalog.GetString("Simulated");
+
+			new DialogMessage(Constants.MessageTypes.INFO, message);
+		}
+	}
+	
 	// Reactive jump 
 	public void PrepareJumpReactiveGraph(double lastTv, double lastTc, string tvString, string tcString, 
 			bool volumeOn, RepetitiveConditionsWindow repetitiveConditionsWin) {
@@ -633,7 +665,7 @@ public partial class ChronoJumpWindow
 			
 
 	// run simple
-	public void PrepareRunSimpleGraph(PrepareEventGraphRunSimple eventGraph)
+	public void PrepareRunSimpleGraph(PrepareEventGraphRunSimple eventGraph, bool animate)
 	{
 		//check graph properties window is not null (propably user has closed it with the DeleteEvent
 		//then create it, but not show it
@@ -647,9 +679,11 @@ public partial class ChronoJumpWindow
 		int bottomMargin = 0; 
 
 		//if max value of graph is automatic
-		if(eventGraphConfigureWin.Max == -1)
+		if(eventGraphConfigureWin.Max == -1) {
 			maxValue = eventGraph.sessionMAXAtSQL;
-		else {
+			if(eventGraph.personMAXAtSQLAllSessions > maxValue)
+				maxValue = eventGraph.personMAXAtSQLAllSessions;
+		} else {
 			maxValue = eventGraphConfigureWin.Max;
 			topMargin = 0;
 		}
@@ -671,7 +705,7 @@ public partial class ChronoJumpWindow
 		//}
 			
 			paintRunSimple (event_execute_drawingarea, eventGraph,
-					maxValue, minValue, topMargin, bottomMargin);
+					maxValue, minValue, topMargin, bottomMargin, animate);
 		
 		
 		// -- refresh
@@ -769,7 +803,7 @@ public partial class ChronoJumpWindow
 		event_execute_drawingarea.QueueDraw();
 	}
 	
-	public void PrepareReactionTimeGraph(PrepareEventGraphReactionTime eventGraph) 
+	public void PrepareReactionTimeGraph(PrepareEventGraphReactionTime eventGraph, bool animate) 
 	{
 		//check graph properties window is not null (propably user has closed it with the DeleteEvent
 		//then create it, but not show it
@@ -798,7 +832,7 @@ public partial class ChronoJumpWindow
 		
 		//paint graph
 		paintReactionTime (event_execute_drawingarea, eventGraph,
-				maxValue, minValue, topMargin, bottomMargin);
+				maxValue, minValue, topMargin, bottomMargin, animate);
 
 		// -- refresh
 		event_execute_drawingarea.QueueDraw();
@@ -887,17 +921,44 @@ public partial class ChronoJumpWindow
 	}
 	
 	private void paintJumpSimple (Gtk.DrawingArea drawingarea, PrepareEventGraphJumpSimple eventGraph, 
-			double maxValue, double minValue, int topMargin, int bottomMargin)
+			double maxValue, double minValue, int topMargin, int bottomMargin, bool animate)
 	{
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
 		
+		//fix problem on show graph at Chronojump start
+		if(event_execute_drawingarea == null || event_execute_pixmap == null)
+			return;
+
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
 		//writeMarginsText(eventGraph.sessionMAXAtSQL, minValue, alto);
 
 		//check now here that we will have not division by zero problems
 		if(maxValue - minValue <= 0)
 			return;
+		
+		//paint first the horizontal guides in order to be behind the bars of each jump
+		drawGuideOrAVG(pen_black_90, eventGraph.sessionMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+		drawGuideOrAVG(pen_black_discont, eventGraph.sessionAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+		
+		drawGuideOrAVG(pen_magenta, eventGraph.personMAXAtSQLAllSessions, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+
+		//if currentPerson has not jumped on this session, 
+		// if has jumped on another session, magenta line: personMAXAtSQLAllSessions will be displayed
+		// if other persons have been jumped on this session, eventGraph.sessionMAXAtSQL and eventGraph.sessionAVGAtSQL will be displayed
+		// don't need the rest of the method
+		if(eventGraph.jumpsAtSQL.Length == 0)
+			return;
+		
+		//if person max in all sessions == person max this session, this session max will be only at left,
+		//overwriting maxAllSesions that will be only at right
+		if(eventGraph.personMAXAtSQLAllSessions == eventGraph.personMAXAtSQL)
+			drawGuideOrAVG(pen_yellow, eventGraph.personMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.LEFT);
+		else
+			drawGuideOrAVG(pen_yellow, eventGraph.personMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+
+		drawGuideOrAVG(pen_yellow_discont, eventGraph.personAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+
 
 		//calculate separation between series and bar width
 		int tctfSep = 0; //separation between tc and tf
@@ -908,21 +969,15 @@ public partial class ChronoJumpWindow
 		int barWidth = Convert.ToInt32(.3*distanceBetweenCols);
 		int barDesplLeft = Convert.ToInt32(.5*barWidth);
 
-		//paint first the average horizontal guides in order to be behind the bars
-		drawGuideOrAVG(pen_black_90, eventGraph.sessionMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		drawGuideOrAVG(pen_black_discont, eventGraph.sessionAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		
-		drawGuideOrAVG(pen_yellow, eventGraph.personMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		drawGuideOrAVG(pen_yellow_discont, eventGraph.personAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-
-		bool animate;
+		bool animateBar = animate;
 		int x = 0;
 		int y = 0;
 		int count = eventGraph.jumpsAtSQL.Length;
 		foreach(string myStr in eventGraph.jumpsAtSQL) 
 		{
 			string [] jump = myStr.Split(new char[] {':'});
-		
+	
+			//if tc, maybe also tv	
 			if(eventGraph.tc > 0) {
 				//small layout when tc and tv and there are more than 4 jumps
 				Pango.Layout layout = layoutMid;
@@ -930,30 +985,30 @@ public partial class ChronoJumpWindow
 					layout = layoutSmall;
 				
 				//do not animate last tc, if tv is animated because then tc is not shown
-				animate = true;
 				if(eventGraph.tv >0)
-					animate = false;
+					animateBar = false;
 
 				x = Convert.ToInt32((ancho-event_execute_rightMargin)*(count-.5)/eventGraph.jumpsAtSQL.Length)-barDesplLeft;
 				y = calculatePaintHeight(Convert.ToDouble(jump[6]), alto, maxValue, minValue, topMargin, bottomMargin);
 				
 				drawBar(x, y, barWidth, alto, pen_rojo, count == eventGraph.jumpsAtSQL.Length,
-						jump[11] == "-1", Convert.ToDouble(jump[6]), layout, animate);
+						jump[11] == "-1", Convert.ToDouble(jump[6]), layout, animateBar);
 			
+				//tv	
 				if(eventGraph.tv > 0) {
 					x = Convert.ToInt32((ancho-event_execute_rightMargin)*(count-.5)/eventGraph.jumpsAtSQL.Length)-barDesplLeft +tctfSep;
 					y = calculatePaintHeight(Convert.ToDouble(jump[5]), alto, maxValue, minValue, topMargin, bottomMargin);
 					
 					drawBar(x, y, barWidth, alto, pen_azul_claro, count == eventGraph.jumpsAtSQL.Length,
-							jump[11] == "-1", Convert.ToDouble(jump[5]), layout, true);
+							jump[11] == "-1", Convert.ToDouble(jump[5]), layout, animateBar);
 				}
-			} else { //if only tv show height
+			} else { //as not tc. Show only height
 				x = Convert.ToInt32((ancho-event_execute_rightMargin)*(count-.5)/eventGraph.jumpsAtSQL.Length)-barDesplLeft +tctfSep;
 				y = calculatePaintHeight(Convert.ToDouble(Util.GetHeightInCentimeters(jump[5])), 
 						alto, maxValue, minValue, topMargin, bottomMargin);
 
 				drawBar(x, y, barWidth, alto, pen_azul_claro, count == eventGraph.jumpsAtSQL.Length,
-						jump[11] == "-1", Convert.ToDouble(Util.GetHeightInCentimeters(jump[5])), layoutMid, true);
+						jump[11] == "-1", Convert.ToDouble(Util.GetHeightInCentimeters(jump[5])), layoutMid, animateBar);
 			}
 			count --;
 		}
@@ -1063,7 +1118,7 @@ public partial class ChronoJumpWindow
 	}
 
 	private void paintRunSimple (Gtk.DrawingArea drawingarea, PrepareEventGraphRunSimple eventGraph,
-			double maxValue, double minValue, int topMargin, int bottomMargin)
+			double maxValue, double minValue, int topMargin, int bottomMargin, bool animate)
 	{
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
@@ -1075,12 +1130,6 @@ public partial class ChronoJumpWindow
 		if(maxValue - minValue <= 0)
 			return;
 		
-		//calculate bar width
-		int distanceBetweenCols = Convert.ToInt32((ancho-event_execute_rightMargin)*(1+.5)/eventGraph.runsAtSQL.Length) -
-			Convert.ToInt32((ancho-event_execute_rightMargin)*(0+.5)/eventGraph.runsAtSQL.Length);
-		int barWidth = Convert.ToInt32(.3*distanceBetweenCols);
-		int barDesplLeft = Convert.ToInt32(.5*barWidth);
-
 		/*
 		//paint reference guide black and green if needed
 		drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
@@ -1089,10 +1138,32 @@ public partial class ChronoJumpWindow
 
 		//blue for TF
 			
-		drawGuideOrAVG(pen_black_90, eventGraph.sessionMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		drawGuideOrAVG(pen_black_discont, eventGraph.sessionAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		drawGuideOrAVG(pen_yellow, eventGraph.personMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		drawGuideOrAVG(pen_yellow_discont, eventGraph.personAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
+		drawGuideOrAVG(pen_black_90, eventGraph.sessionMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+		drawGuideOrAVG(pen_black_discont, eventGraph.sessionAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+		drawGuideOrAVG(pen_magenta, eventGraph.personMAXAtSQLAllSessions, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+		
+		//if currentPerson has not run on this session, 
+		// if has run on another session, magenta line: personMAXAtSQLAllSessions will be displayed
+		// if other persons have run on this session, eventGraph.sessionMAXAtSQL and eventGraph.sessionAVGAtSQL will be displayed
+		// don't need the rest of the method
+		if(eventGraph.runsAtSQL.Length == 0)
+			return;
+		
+		//if person max in all sessions == person max this session, this session max will be only at left,
+		//overwriting maxAllSesions that will be only at right
+		if(eventGraph.personMAXAtSQLAllSessions == eventGraph.personMAXAtSQL)
+			drawGuideOrAVG(pen_yellow, eventGraph.personMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.LEFT);
+		else
+			drawGuideOrAVG(pen_yellow, eventGraph.personMAXAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+
+		drawGuideOrAVG(pen_yellow_discont, eventGraph.personAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+
+		//calculate bar width
+		int distanceBetweenCols = Convert.ToInt32((ancho-event_execute_rightMargin)*(1+.5)/eventGraph.runsAtSQL.Length) -
+			Convert.ToInt32((ancho-event_execute_rightMargin)*(0+.5)/eventGraph.runsAtSQL.Length);
+		int barWidth = Convert.ToInt32(.3*distanceBetweenCols);
+		int barDesplLeft = Convert.ToInt32(.5*barWidth);
+
 
 		int x = 0;
 		int y = 0;
@@ -1105,7 +1176,7 @@ public partial class ChronoJumpWindow
 						topMargin, bottomMargin);
 
 				drawBar(x, y, barWidth, alto, pen_azul_claro, count == eventGraph.runsAtSQL.Length,
-						run[8] == "-1", Convert.ToDouble(run[5])/Convert.ToDouble(run[6]), layoutMid, true);
+						run[8] == "-1", Convert.ToDouble(run[5])/Convert.ToDouble(run[6]), layoutMid, animate);
 			}
 
 			count --;
@@ -1115,7 +1186,7 @@ public partial class ChronoJumpWindow
 	}
 	
 	private void paintReactionTime (Gtk.DrawingArea drawingarea, PrepareEventGraphReactionTime eventGraph,
-			double maxValue, double minValue, int topMargin, int bottomMargin)
+			double maxValue, double minValue, int topMargin, int bottomMargin, bool animate)
 	{
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
@@ -1139,10 +1210,10 @@ public partial class ChronoJumpWindow
 		drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
 		*/
 
-		drawGuideOrAVG(pen_black_90, eventGraph.sessionMINAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		drawGuideOrAVG(pen_black_discont, eventGraph.sessionAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		drawGuideOrAVG(pen_yellow, eventGraph.personMINAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-		drawGuideOrAVG(pen_yellow_discont, eventGraph.personAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
+		drawGuideOrAVG(pen_black_90, eventGraph.sessionMINAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+		drawGuideOrAVG(pen_black_discont, eventGraph.sessionAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+		drawGuideOrAVG(pen_yellow, eventGraph.personMINAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+		drawGuideOrAVG(pen_yellow_discont, eventGraph.personAVGAtSQL, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 
 		int x = 0;
 		int y = 0;
@@ -1154,7 +1225,7 @@ public partial class ChronoJumpWindow
 					topMargin, bottomMargin);
 
 			drawBar(x, y, barWidth, alto, pen_azul_claro, count == eventGraph.rtsAtSQL.Length,
-					rts[7] == "-1", Convert.ToDouble(rts[5]), layoutMid, true);
+					rts[7] == "-1", Convert.ToDouble(rts[5]), layoutMid, animate);
 
 			count --;
 		}
@@ -1183,15 +1254,15 @@ public partial class ChronoJumpWindow
 
 			if(jumps > 1) {
 				//blue tf average discountinuos line	
-				drawGuideOrAVG(pen_azul_discont, avgTV, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
+				drawGuideOrAVG(pen_azul_discont, avgTV, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 
 				//red tc average discountinuos line	
-				drawGuideOrAVG(pen_rojo_discont, avgTC, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
+				drawGuideOrAVG(pen_rojo_discont, avgTC, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 			}
 
 			//paint reference guide black and green if needed
-			drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
+			drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 
 			
 			//blue tf evolution	
@@ -1392,8 +1463,8 @@ public partial class ChronoJumpWindow
 			*/
 
 			//paint reference guide black and green if needed
-			drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
+			drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 
 			string [] myTimesStringFull = timesString.Split(new char[] {'='});
 			int count = 0;
@@ -1547,11 +1618,11 @@ public partial class ChronoJumpWindow
 		if(maxValue - minValue > 0) {
 
 			//blue time average discountinuos line	
-			drawGuideOrAVG(pen_azul_discont, avgTime, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
+			drawGuideOrAVG(pen_azul_discont, avgTime, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 
 			//paint reference guide black and green if needed
-			drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
-			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
+			drawGuideOrAVG(pen_black_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
+			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue, guideWidthEnum.FULL);
 
 			//blue time evolution	
 			string [] myTimesStringFull = timesString.Split(new char[] {'='});
@@ -1792,15 +1863,30 @@ public partial class ChronoJumpWindow
 		event_execute_pixmap.DrawLayout (myPen, ancho -event_execute_rightMargin, (int)calculatePaintHeight(myValue, alto, maxValue, minValue, topMargin, bottomMargin) -7, layoutSmall); //-7 for aligning (is baseline) (font is Courier 7)
 	}
 
-		
-	private void drawGuideOrAVG(Gdk.GC myPen, double guideHeight, int alto, int ancho, int topMargin, int bottomMargin, double maxValue, double minValue) 
+	enum guideWidthEnum { FULL, LEFT, RIGHT }
+	private void drawGuideOrAVG(Gdk.GC myPen, double guideHeight, int alto, int ancho, int topMargin, int bottomMargin, double maxValue, double minValue, guideWidthEnum guideWidth ) 
 	{
 		if(guideHeight == -1)
 			return; //return if checkbox guide is not checked
 		else {
+			int xLeft;
+			int xRight;
+			if(guideWidth == guideWidthEnum.FULL) {
+				xLeft = 10;
+				xRight = ancho - event_execute_rightMargin-2;
+			}
+			else if(guideWidth == guideWidthEnum.LEFT) {
+				xLeft = 10;
+				xRight = Convert.ToInt32((ancho - event_execute_rightMargin-2) / 2);
+			}
+			else {	// RIGHT
+				xLeft = Convert.ToInt32((ancho - event_execute_rightMargin-2) / 2);
+				xRight = ancho - event_execute_rightMargin-2;
+			}
+
 			event_execute_pixmap.DrawLine(myPen, 
-					10, calculatePaintHeight(guideHeight, alto, maxValue, minValue, topMargin, bottomMargin),
-					ancho - event_execute_rightMargin-2, calculatePaintHeight(guideHeight, alto, maxValue, minValue, topMargin, bottomMargin));
+					xLeft, calculatePaintHeight(guideHeight, alto, maxValue, minValue, topMargin, bottomMargin),
+					xRight, calculatePaintHeight(guideHeight, alto, maxValue, minValue, topMargin, bottomMargin));
 			//write textual data
 			layoutSmall.SetMarkup((Math.Round(guideHeight,1)).ToString());
 			event_execute_pixmap.DrawLayout (pen_gris, ancho -event_execute_rightMargin, (int)calculatePaintHeight(guideHeight, alto, maxValue, minValue, topMargin, bottomMargin) -7, layoutSmall); //-7 for aligning with Courier 7 font baseline
@@ -1866,7 +1952,7 @@ public partial class ChronoJumpWindow
 		switch (currentEventType.Type) {
 			case EventType.Types.JUMP:
 				if(thisJumpIsSimple) 
-					PrepareJumpSimpleGraph(currentEventExecute.PrepareEventGraphJumpSimpleObject);
+					PrepareJumpSimpleGraph(currentEventExecute.PrepareEventGraphJumpSimpleObject, true);
 				else {
 					PrepareJumpReactiveGraph(
 							currentEventExecute.PrepareEventGraphJumpReactiveObject.lastTv, 
@@ -1878,7 +1964,7 @@ public partial class ChronoJumpWindow
 				break;
 			case EventType.Types.RUN:
 				if(thisRunIsSimple)
-					PrepareRunSimpleGraph(currentEventExecute.PrepareEventGraphRunSimpleObject);
+					PrepareRunSimpleGraph(currentEventExecute.PrepareEventGraphRunSimpleObject, true);
 				else {
 					bool volumeOnHere = preferences.volumeOn;
 					//do not play good or bad sounds at RSA because we need to hear the GO sound
@@ -1896,7 +1982,7 @@ public partial class ChronoJumpWindow
 				}
 				break;
 			case EventType.Types.REACTIONTIME:
-					PrepareReactionTimeGraph(currentEventExecute.PrepareEventGraphReactionTimeObject);
+					PrepareReactionTimeGraph(currentEventExecute.PrepareEventGraphReactionTimeObject, true);
 				break;
 			case EventType.Types.PULSE:
 					PreparePulseGraph(
@@ -1971,6 +2057,7 @@ public partial class ChronoJumpWindow
 	Gdk.GC pen_yellow; //person max
 	Gdk.GC pen_yellow_discont; //person avg
 	Gdk.GC pen_yellow_bg; //below person result bar
+	Gdk.GC pen_magenta; //person max all sessions
 	Gdk.GC pen_black_discont; //guide
 	Gdk.GC pen_black_bars; //big borders of rectangle (last event)
 	Gdk.GC pen_green_discont; //guide
@@ -1991,6 +2078,7 @@ public partial class ChronoJumpWindow
 		Gdk.Color black_90 = new Gdk.Color(0x33,0x33,0x33); 
 		Gdk.Color yellow = new Gdk.Color(0xff,0xcc,0x01);
 		Gdk.Color yellow_bg = new Gdk.Color(0xff,0xee,0x66);
+		Gdk.Color magenta = new Gdk.Color(0xff,0x39,0xff);
 		Gdk.Color green = new Gdk.Color(0,0xff,0);
 		Gdk.Color gris = new Gdk.Color(0x66,0x66,0x66);
 		Gdk.Color beige = new Gdk.Color(0x99,0x99,0x99);
@@ -2005,6 +2093,7 @@ public partial class ChronoJumpWindow
 		colormap.AllocColor (ref black,true,true);
 		colormap.AllocColor (ref yellow,true,true);
 		colormap.AllocColor (ref yellow_bg,true,true);
+		colormap.AllocColor (ref magenta,true,true);
 		colormap.AllocColor (ref green,true,true);
 		colormap.AllocColor (ref gris,true,true);
 		colormap.AllocColor (ref beige,true,true);
@@ -2017,6 +2106,7 @@ public partial class ChronoJumpWindow
 		pen_yellow = new Gdk.GC(event_execute_drawingarea.GdkWindow);
 		pen_yellow_discont = new Gdk.GC(event_execute_drawingarea.GdkWindow);
 		pen_yellow_bg = new Gdk.GC(event_execute_drawingarea.GdkWindow);
+		pen_magenta = new Gdk.GC(event_execute_drawingarea.GdkWindow);
 		pen_azul_claro = new Gdk.GC(event_execute_drawingarea.GdkWindow);
 		pen_azul = new Gdk.GC(event_execute_drawingarea.GdkWindow);
 		pen_rojo_discont = new Gdk.GC(event_execute_drawingarea.GdkWindow);
@@ -2050,6 +2140,7 @@ public partial class ChronoJumpWindow
 		pen_yellow.Foreground = yellow;
 		pen_yellow_discont.Foreground = yellow;
 		pen_yellow_bg.Foreground = yellow_bg;
+		pen_magenta.Foreground = magenta;
 		pen_black_bars.Foreground = black;
 		//pen_white.Foreground = white;
 
