@@ -113,47 +113,48 @@ public class GenericWindow
 	public int uniqueID;
 	public string nameUntranslated;
 
-	public enum Types { UNDEFINED, ENCODER_SESSION_LOAD, ENCODER_SEL_REPS };
+	public enum Types { UNDEFINED, ENCODER_SESSION_LOAD, 
+		ENCODER_SEL_REPS_IND_CURRENT_SESS, ENCODER_SEL_REPS_IND_ALL_SESS, ENCODER_SEL_REPS_GROUP_CURRENT_SESS };
 	//used to decide if a genericWin has to be recreated
 	public Types Type;
 
 
-	public GenericWindow ()
+	public GenericWindow (string textHeader)
 	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "generic_window", "chronojump");
 		gladeXML.Autoconnect(this);
-		
+	
 		//put an icon to window
 		UtilGtk.IconWindow(generic_window);
+		
+		hideWidgets();
+		generic_window.Resizable = false;
+		label_header.Text = textHeader;
+		
+		HideOnAccept = true;
+		DestroyOnAccept = false;
 	}
 
 	//for some widgets
 	static public GenericWindow Show (bool showNow, string textHeader, ArrayList array)
 	{
 		if (GenericWindowBox == null) {
-			GenericWindowBox = new GenericWindow();
+			GenericWindowBox = new GenericWindow(textHeader);
 		}
 
-		GenericWindowBox.hideWidgets();
-	
 		foreach(ArrayList widgetArray in array)
 			GenericWindowBox.showWidgetsPowerful(widgetArray);
 
-		GenericWindowBox.generic_window.Resizable = false;
-		GenericWindowBox.label_header.Text = textHeader;
-		
 		Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
 		GenericWindowBox.image_delete.Pixbuf = pixbuf;
 
-		GenericWindowBox.label_header.Text = textHeader;
-
 		GenericWindowBox.Type = Types.UNDEFINED;
 		
+		GenericWindowBox.label_header.Text = textHeader;
+		
 		if(showNow)
 			GenericWindowBox.generic_window.Show ();
-		GenericWindowBox.HideOnAccept = true;
-		GenericWindowBox.DestroyOnAccept = false;
 		
 		return GenericWindowBox;
 	}
@@ -162,23 +163,24 @@ public class GenericWindow
 	static public GenericWindow Show (string textHeader, Constants.GenericWindowShow stuff)
 	{
 		if (GenericWindowBox == null) {
-			GenericWindowBox = new GenericWindow();
+			GenericWindowBox = new GenericWindow(textHeader);
 		}
+		
+		GenericWindowBox.Type = Types.UNDEFINED;
 
-		GenericWindowBox.hideWidgets();
 		GenericWindowBox.showWidget(stuff);
-
-		GenericWindowBox.generic_window.Resizable = false;
-		GenericWindowBox.label_header.Text = textHeader;
 		GenericWindowBox.generic_window.Show ();
-		GenericWindowBox.HideOnAccept = true;
-		GenericWindowBox.DestroyOnAccept = false;
 		
 		return GenericWindowBox;
 	}
 	
 	public void ShowNow() {
-		generic_window.Show ();
+		if(GenericWindowBox == null) {
+			LogB.Error("at showNow GenericWindowBox is null!!");
+		//	GenericWindowBox = new GenericWindow("");
+		}
+
+		GenericWindowBox.generic_window.Show ();
 	}
 	
 	
@@ -629,17 +631,17 @@ public class GenericWindow
 
 		return 0;
 	}
-	public string GetCheckboxStatus(int uniqueID) {
+	public bool GetCheckboxStatus(int uniqueID) {
 		Gtk.TreeIter iter;
 		bool okIter = store.GetIterFirst(out iter);
 		if(okIter) {
 			do {
 				if( ((string) store.GetValue (iter, 0)) == uniqueID.ToString())
-					return store.GetValue (iter, 1).ToString();
+					return (bool) store.GetValue (iter, 1);
 			} while ( store.IterNext(ref iter) );
 		}
-		//if error, return
-		return "inactive";
+		//if error, return false
+		return false;
 	}
 	//if column == 1 returns checkboxes column. If is 2 returns column 2...
 	//Attention: Used on checkboxes treeviews
@@ -828,13 +830,7 @@ public class GenericWindow
 	public void ShowButtonDelete(bool show) {
 		button_delete.Visible = show;
 	}
-	
-	private void on_button_delete_clicked (object o, EventArgs args)
-	{
-		GenericWindowBox.generic_window.Hide();
-		GenericWindowBox = null;
-	}
-	
+
 	public void SetButtonAcceptLabel(string str) {
 		button_accept.Label=str;
 	}
@@ -856,9 +852,11 @@ public class GenericWindow
 		GenericWindowBox.generic_window.Hide();
 		GenericWindowBox = null;
 	}
-	
+
 	private void on_delete_event (object o, DeleteEventArgs args)
 	{
+		LogB.Information("calling on_delete_event");
+
 		args.RetVal = true;
 			
 		GenericWindowBox.generic_window.Hide();
@@ -867,6 +865,8 @@ public class GenericWindow
 
 	private void on_button_accept_clicked (object o, EventArgs args)
 	{
+		LogB.Information("called on_button_accept_clicked");
+
 		if(HideOnAccept)
 			GenericWindowBox.generic_window.Hide();
 		if(DestroyOnAccept)
@@ -880,6 +880,12 @@ public class GenericWindow
 		GenericWindowBox = null;
 	}
 	
+	public bool GenericWindowBoxIsNull() {
+		if(GenericWindowBox == null)
+			return true;
+		return false;
+	}
+	
 	public Button Button_middle {
 		get { return button_middle; }
 	}
