@@ -74,6 +74,7 @@ public class SessionAddEditWindow {
 	bool addSession;
 	
 	private Session currentSession;
+	private Gtk.Button fakeButtonAccept;
 	
 	GenericWindow genericWin;
 	static SessionAddEditWindow SessionAddEditWindowBox;
@@ -91,6 +92,8 @@ public class SessionAddEditWindow {
 	
 		this.currentSession = currentSession;
 		button_accept.Sensitive = false;
+		
+		fakeButtonAccept = new Button();
 
 		createComboSports();
 		createComboSpeciallities(-1);
@@ -562,9 +565,12 @@ public class SessionAddEditWindow {
 	{
 		//check if name of session exists (is owned by other session),
 		//but all is ok if the name is the same as the old name (editing)
-		bool sessionNameExists = Sqlite.Exists (false, Constants.SessionTable, Util.RemoveTildeAndColon(entry_name.Text));
-		if(sessionNameExists && Util.RemoveTildeAndColon(entry_name.Text) != currentSession.Name ) {
-			string myString = string.Format(Catalog.GetString("Session: '{0}' exists. Please, use another name"), Util.RemoveTildeAndColonAndDot(entry_name.Text) );
+		string name = Util.RemoveTildeAndColon(entry_name.Text);
+		name = Util.RemoveChar(name, '"');
+
+		bool sessionNameExists = Sqlite.Exists (false, Constants.SessionTable, name);
+		if(sessionNameExists && name != currentSession.Name ) {
+			string myString = string.Format(Catalog.GetString("Session: '{0}' exists. Please, use another name"), name);
 			ErrorWindow.Show(myString);
 		} else {
 			int sportID;
@@ -586,42 +592,48 @@ public class SessionAddEditWindow {
 			else
 				levelID = Util.FetchID(UtilGtk.ComboGetActive(combo_levels));
 
+			string place = Util.RemoveTildeAndColon(entry_place.Text);
+			string comments = Util.RemoveTildeAndColon(textview.Buffer.Text);
+			place = Util.RemoveChar(place, '"');
+			comments = Util.RemoveChar(comments, '"');
+
 			if(addSession) 
-				currentSession = new Session (Util.RemoveTildeAndColon(entry_name.Text), 
-						Util.RemoveTildeAndColon(entry_place.Text), 
+				currentSession = new Session (name, place,
 						dateTime,
 						sportID, speciallityID, levelID,
-						Util.RemoveTildeAndColon(textview.Buffer.Text),
+						comments,
 						Constants.ServerUndefinedID);
 			else {
-				currentSession.Name = Util.RemoveTildeAndColon(entry_name.Text.ToString());
-				currentSession.Place = Util.RemoveTildeAndColon(entry_place.Text.ToString()); 
+				currentSession.Name = name;
+				currentSession.Place = place;
 				currentSession.Date = dateTime;
 				currentSession.PersonsSportID = sportID;
 				currentSession.PersonsSpeciallityID = speciallityID;
 				currentSession.PersonsPractice = levelID;
-				currentSession.Comments = Util.RemoveTildeAndColon(textview.Buffer.Text);
+				currentSession.Comments = comments;
 
 				SqliteSession.Update(currentSession.UniqueID, currentSession.Name, 
 						currentSession.Place, currentSession.Date, 
 						sportID, speciallityID, levelID,
 						currentSession.Comments);
 			}
+			
+			FakeButtonAccept.Click();
+		}
+	}
 
+	public void HideAndNull() {
+		if (SessionAddEditWindowBox != null) {
 			SessionAddEditWindowBox.session_add_edit.Hide();
 			SessionAddEditWindowBox = null;
 		}
 	}
 
-	public Button Button_accept 
+	public Gtk.Button FakeButtonAccept
 	{
-		set {
-			button_accept = value;	
-		}
-		get {
-			return button_accept;
-		}
+		get { return fakeButtonAccept; }
 	}
+	
 
 	public Session CurrentSession 
 	{
@@ -739,8 +751,12 @@ public class SessionLoadWindow {
 			tv.AppendColumn ( Catalog.GetString ("MultiChronopic"), new CellRendererText(), "text", count++);
 		}
 		if(showEncoder) {
-			tv.AppendColumn ( Catalog.GetString ("Encoder sets"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Encoder repetitions"), new CellRendererText(), "text", count++);
+			tv.AppendColumn ( Catalog.GetString ("Gravitatory encoder") + "\n" +
+					Catalog.GetString("Sets") + " ; " + Catalog.GetString("Repetitions"),
+					new CellRendererText(), "text", count++);
+			tv.AppendColumn ( Catalog.GetString ("Inertial encoder") + "\n" +
+					Catalog.GetString("Sets") + " ; " + Catalog.GetString("Repetitions"),
+					new CellRendererText(), "text", count++);
 		}
 		tv.AppendColumn ( Catalog.GetString ("Comments"), new CellRendererText(), "text", count++);
 	}
@@ -860,6 +876,21 @@ public class SessionLoadWindow {
 
 	}
 	
+	//pass 0 for first row
+	public void SelectRow(int rowNumber)
+	{
+		TreeIter iter;
+		bool iterOk = store.GetIterFirst(out iter);
+		if(iterOk) {
+			int count = 0;
+			while (count < rowNumber) {
+				store.IterNext(ref iter);
+				count ++;
+			}
+			treeview_session_load.Selection.SelectIter(iter);
+		}
+	}
+	
 	private void onSelectionEntry (object o, EventArgs args)
 	{
 		TreeModel model;
