@@ -57,6 +57,7 @@ public class PrepareEventGraphJumpSimple {
 	//sql data of previous jumps to plot graph and show stats at bottom
 	public string [] jumpsAtSQL;
 	
+	public double personMAXAtSQLAllSessions;
 	public double personMAXAtSQL;
 	public double sessionMAXAtSQL;
 
@@ -89,6 +90,7 @@ public class PrepareEventGraphJumpSimple {
 		} else
 			sqlSelect = "TC";
 		
+		personMAXAtSQLAllSessions = SqliteSession.SelectMAXEventsOfAType(true, -1, personID, table, type, sqlSelect);
 		personMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, personID, table, type, sqlSelect);
 		sessionMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, -1, table, type, sqlSelect);
 
@@ -129,6 +131,7 @@ public class PrepareEventGraphRunSimple {
 	//sql data of previous runs to plot graph and show stats at bottom
 	public string [] runsAtSQL;
 	
+	public double personMAXAtSQLAllSessions;
 	public double personMAXAtSQL;
 	public double sessionMAXAtSQL;
 
@@ -152,6 +155,7 @@ public class PrepareEventGraphRunSimple {
 		
 		string sqlSelect = "distance/time";
 		
+		personMAXAtSQLAllSessions = SqliteSession.SelectMAXEventsOfAType(true, -1, personID, table, type, sqlSelect);
 		personMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, personID, table, type, sqlSelect);
 		sessionMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, -1, table, type, sqlSelect);
 		
@@ -233,7 +237,7 @@ public class PrepareEventGraphReactionTime {
 		Sqlite.Open();
 
 		//obtain data
-		rtsAtSQL = SqliteReactionTime.SelectReactionTimes(true, sessionID, personID,
+		rtsAtSQL = SqliteReactionTime.SelectReactionTimes(true, sessionID, personID, type,
 				Sqlite.Orders_by.ID_DESC, 10); //select only last 10
 		
 		personMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(
