@@ -59,7 +59,8 @@ public enum LogEntryType
 	Error,
 	Information,
 	SQL, SQLon, SQLoff,
-	ThreadStart, ThreadEnding, ThreadEnded
+	ThreadStart, ThreadEnding, ThreadEnded,
+	TestStart, TestEnd
 }
 
 public class LogEntry
@@ -102,6 +103,48 @@ public class LogEntry
 	}
 }
 
+/*
+ * LogB Console.Write is written to a file. see log.Start() at log.cs
+ * is done by
+ * 	System.Console.SetOut(sw);
+ * 	System.Console.SetError(sw);
+ * 	sw.AutoFlush = true;
+ * and this is not threadsafe.
+ * We store a string on this class with the Log that will be pushed to Console -> StreamWriter, only by the main thread
+ */
+// Based on O'Reilly C# Cookbook p. 1015
+public static class LogSync
+{
+	private static string logPending;
+	private static object syncObj = new object();
+
+	//only called one time (at Chronojump Main())
+	public static void Initialize()
+	{
+		logPending = "";
+	}
+
+	//called by threads 2 and above
+	public static void Add(string str)
+	{
+		lock(syncObj)
+		{
+			logPending += str;
+		}
+	}
+	
+	//called by thread 1 (GTK)
+	public static string ReadAndEmpty()
+	{
+		lock(syncObj)
+		{
+			string str = logPending;
+			logPending = "";
+			return str;
+		}
+	}
+}
+
 //copied from Banshee project
 //called LogB because in Chronojump there's already a Log class that will be deprecated soon
 public static class LogB
@@ -167,30 +210,51 @@ public static class LogB
 					ConsoleCrayon.BackgroundColor = ConsoleColor.Red;
 					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
 					break;
+				case LogEntryType.TestStart:
+					ConsoleCrayon.BackgroundColor = ConsoleColor.Blue;
+					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
+					break;
+				case LogEntryType.TestEnd:
+					ConsoleCrayon.BackgroundColor = ConsoleColor.Blue;
+					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
+					break;
 			}
 
 			var thread_name = String.Empty;
+			bool printNow = false;
 			if(Debugging) {
 				var thread = Thread.CurrentThread;
 				thread_name = thread.ManagedThreadId.ToString();
-				if(thread_name == "1")
+				if(thread_name == "1") {
+					printNow = true;
 					thread_name = "1-GTK ";
-				else
+				} else 
 					thread_name += "     ";
 			}
 
-			Console.Write("[{5}{0} {1:00}:{2:00}:{3:00}.{4:000}]", TypeString(type), DateTime.Now.Hour,
+			string lineStart = string.Format("[{5}{0} {1:00}:{2:00}:{3:00}.{4:000}]", TypeString(type), DateTime.Now.Hour,
 					DateTime.Now.Minute, DateTime.Now.Second, DateTime.Now.Millisecond, thread_name);
 
-			ConsoleCrayon.ResetColor();
-
-			if(details != null) {
-				Console.WriteLine(" {0} - {1}", message, details);
+			if(printNow) {
+				//try {
+					Console.Write(lineStart);
+	
+					ConsoleCrayon.ResetColor();
+	
+					message += LogSync.ReadAndEmpty();
+	
+					if(details != null) {
+						Console.WriteLine(" {0} - {1}", message, details);
+					} else {
+						if(type == LogEntryType.Debug)
+							Console.Write(" {0}", message);
+						else
+							Console.WriteLine(" {0}", message);
+					}
+				//} catch (System.IndexOutOfRangeException e) {
+				//}
 			} else {
-				if(type == LogEntryType.Debug)
-					Console.Write(" {0}", message);
-				else
-					Console.WriteLine(" {0}", message);
+				LogSync.Add(lineStart + "\n" + message);
 			}
 		}
 
@@ -222,6 +286,10 @@ public static class LogB
 				return " <.......................... Thread Ending";
 			case LogEntryType.ThreadEnded:
 				return " <-------------------------- Thread Ended";
+			case LogEntryType.TestStart:
+				return "Test Start t_t_t_t_t_t_t_t_t_t_->";
+			case LogEntryType.TestEnd:
+				return "Test End <-_t_t_t_t_t_t_t_t_t_t";
 		}
 		return null;
 	}
@@ -491,7 +559,7 @@ public static class LogB
 
 #endregion
 
-#region Public SQL Methods
+#region Public Thread Methods
 	
 	public static void ThreadStart()
 	{
@@ -508,6 +576,29 @@ public static class LogB
 		Commit(LogEntryType.ThreadEnded, null, null, false);
 	}
 
+#endregion
+
+#region Public Test Methods
+	
+	public static void TestStart(string test)
+	{
+		Commit(LogEntryType.TestStart, test, null, false);
+	}
+	
+	public static void TestStart(string test, string details)
+	{
+		Commit(LogEntryType.TestStart, test, details, false);
+	}
+
+	public static void TestEnd(string test)
+	{
+		Commit(LogEntryType.TestEnd, test, null, false);
+	}
+	
+	public static void TestEnd(string test, string details)
+	{
+		Commit(LogEntryType.TestEnd, test, details, false);
+	}
 
 #endregion
 
