@@ -22,6 +22,7 @@ using System;
 using System.Data;
 using System.IO;
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using Mono.Data.Sqlite;
 
 
@@ -211,7 +212,96 @@ class SqliteJump : Sqlite
 
 		return myJump;
 	}
+	
+	public static string [] SelectTestMaxStuff(int personID, JumpType jumpType) 
+	{
+		double tc = 0.0;
+		if(! jumpType.StartIn)
+			tc = 1; //just a mark meaning that tc has to be shown
+
+		double tv = 1;
+		//special cases where there's no tv
+		if(jumpType.Name == Constants.TakeOffName || jumpType.Name == Constants.TakeOffWeightName)
+			tv = 0.0;
+	
+
+		string sqlSelect = "";
+		if(tv > 0) {
+			if(tc <= 0)
+				sqlSelect = "100*4.9*(jump.TV/2)*(jump.TV/2)";
+			else
+				sqlSelect = "jump.TV"; //if tc is higher than tv it will be fixed on PrepareJumpSimpleGraph
+		} else
+			sqlSelect = "jump.TC";
 		
+		Sqlite.Open();
+		dbcmd.CommandText = "SELECT session.date, session.name, MAX(" + sqlSelect + "), jump.simulated " + 
+			" FROM jump, session WHERE type = \"" + jumpType.Name + "\" AND personID = " + personID + 
+			" AND jump.sessionID = session.uniqueID";
+		
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+		reader.Read();
+		
+		string [] str = DataReaderToStringArray(reader, 4);
+		
+		reader.Close();
+		Sqlite.Close();
+
+		return str;
+	}
+	
+	public static List<Double> SelectChronojumpProfile (int pID, int sID)
+	{
+		string personID = pID.ToString();
+		string sessionID = sID.ToString();
+
+		Sqlite.Open();
+		
+		double sj = selectDouble( 
+				"SELECT MAX(tv * tv * 1.226) " +
+				" FROM jump " +
+				" WHERE type = \"SJ\" " +
+				" AND personID = " + personID + " AND sessionID = " + sessionID);
+		
+		double sjl = selectDouble( 
+				"SELECT MAX(tv * tv * 1.226) " +
+				" FROM jump " +
+				" WHERE type = \"SJl\" AND jump.weight = 100 " +
+				" AND personID = " + personID + " AND sessionID = " + sessionID);
+		
+		double cmj = selectDouble( 
+				"SELECT MAX(tv * tv * 1.226) " +
+				" FROM jump " +
+				" WHERE type = \"CMJ\" " +
+				" AND personID = " + personID + " AND sessionID = " + sessionID);
+		
+		double abk = selectDouble( 
+				"SELECT MAX(tv * tv * 1.226) " +
+				" FROM jump " +
+				" WHERE type = \"ABK\" " +
+				" AND personID = " + personID + " AND sessionID = " + sessionID);
+		
+		double dja = selectDouble( 
+				"SELECT MAX(tv * tv * 1.226) " +
+				" FROM jump " +
+				" WHERE type = \"DJa\" " +
+				" AND personID = " + personID + " AND sessionID = " + sessionID);
+
+		Sqlite.Close();
+
+		List<Double> l = new List<Double>();
+		l.Add(sj);
+	        l.Add(sjl);
+	        l.Add(cmj);
+		l.Add(abk);
+		l.Add(dja);
+		return l;
+	}
+
 
 	public static void Update(int jumpID, string type, string tv, string tc, string fall, int personID, double weight, string description, double angle)
 	{
