@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -88,15 +88,15 @@ class SqliteMultiChronopic : Sqlite
 			" cp1InStr, cp1OutStr, cp2InStr, cp2OutStr, cp3InStr, cp3OutStr, cp4InStr, cp4OutStr, " +
 			" vars, description, simulated)" +
 			" VALUES (" + uniqueID + ", " +
-			personID + ", " + sessionID + ", '" + type + "', " +
+			personID + ", " + sessionID + ", \"" + type + "\", " +
 			cp1StartedIn + ", " + cp2StartedIn + ", " +
-			cp3StartedIn + ", " + cp4StartedIn + ", '" +
-			cp1InStr + "', '" + cp1OutStr + "', '" +
-			cp2InStr + "', '" + cp2OutStr + "', '" +
-			cp3InStr + "', '" + cp3OutStr + "', '" +
-			cp4InStr + "', '" + cp4OutStr + "', '" +
-			vars + "', '" +
-			description + "', " + simulated + ")" ;
+			cp3StartedIn + ", " + cp4StartedIn + ", \"" +
+			cp1InStr + "\", \"" + cp1OutStr + "\", \"" +
+			cp2InStr + "\", \"" + cp2OutStr + "\", \"" +
+			cp3InStr + "\", \"" + cp3OutStr + "\", \"" +
+			cp4InStr + "\", \"" + cp4OutStr + "\", \"" +
+			vars + "\", \"" +
+			description + "\", " + simulated + ")" ;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		
@@ -245,9 +245,9 @@ class SqliteMultiChronopic : Sqlite
 	{
 		Sqlite.Open();
 		dbcmd.CommandText = "UPDATE " + Constants.MultiChronopicTable + " SET personID = " + personID + 
-			", vars = '" + vars + 		//vars is distance on runAnalysis
-			"', description = '" + description +
-			"' WHERE uniqueID == " + eventID ;
+			", vars = \"" + vars + 		//vars is distance on runAnalysis
+			"\", description = \"" + description +
+			"\" WHERE uniqueID == " + eventID ;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		Sqlite.Close();
