@@ -22,7 +22,6 @@ using System;
 using System.Data;
 using System.IO;
 using System.Collections; //ArrayList
-using System.Collections.Generic; //List<T>
 using Mono.Unix;
 using Mono.Data.Sqlite;
 
@@ -1378,16 +1377,12 @@ LogB.SQL(intervalSpeeds);
 		return myArray;
 	}
 	
+
+	//all persons in session (unused)
+	/*
+	 * Note criteria of indexes has changed see method above
+	 */
 	/*
-	 * TODO: Al this have to be in % then need all the data to do it
-	maximum values of each jump!!!!
-	all with heights
-	SJ100		F Max
-	SJ-SJ100 	F Expl
-	CMJ-SJ 		Cap. Elastica (hability)
-	ABK-CMJ 	Cap. Braços (hability)
-	DJa		F Reactiu-reflexa
-	*/
 	public static ArrayList SelectChronojumpProfile (string sessionID)
 	{
 		Sqlite.Open();
@@ -1453,5 +1448,6 @@ LogB.SQL(intervalSpeeds);
 		Sqlite.Close();
 		return arrayReturn;
 	}
+	*/
 
 }
