@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -1514,7 +1514,8 @@ public class Stat
 				new DialogMessage(Constants.MessageTypes.WARNING, 
 						Catalog.GetString("Sorry. Error doing graph.") + 
 						"\n" + Catalog.GetString("Maybe R is not installed.") + 
-						"\n\nhttp://www.r-project.org/");
+						"\n" + Catalog.GetString("Please, install it from here:") +
+						"\n\nhttp://cran.cnr.berkeley.edu/bin/macosx/R-latest.pkg");
 			else
 				new DialogImageTest(Catalog.GetString("Chronojump Graph"), fileName, DialogImageTest.ArchiveType.FILE);
 		}
