@@ -359,7 +359,7 @@ public class UtilEncoder
 
 	//Inertia Momentum
 	//TODO: make this work with encoderRProc
-	public static void RunEncoderCalculeIM(double weight, double length, EncoderRProcAnalyze encoderRProcAnalyze) 
+	public static void RunEncoderCalculeIM(double weight, double distance, EncoderRProcAnalyze encoderRProcAnalyze) 
 	{
 		encoderRProcAnalyze.CancelRScript = false;
 
@@ -396,7 +396,7 @@ public class UtilEncoder
 			inputData + "\n" + 
 			outputData + "\n" + 
 			Util.ConvertToPoint(weight) + "\n" + 
-			Util.ConvertToPoint(length) + "\n" +
+			Util.ConvertToPoint(distance) + "\n" +
 			scriptUtilR + "\n";
 
 		string optionsFile = Path.GetTempPath() + "Roptions.txt";
@@ -713,12 +713,17 @@ public class UtilEncoder
 			contents = contentsReversed;
 		}
 
-		
-		TextWriter writer = File.CreateText(fileCurveFull);
-		writer.Write(contents);
-		writer.Flush();
-		writer.Close();
-		((IDisposable)writer).Dispose();
+		try {
+			TextWriter writer = File.CreateText(fileCurveFull);
+			writer.Write(contents);
+			writer.Flush();
+			writer.Close();
+			((IDisposable)writer).Dispose();
+		}
+		catch {
+			LogB.Error("Problems on EncoderSaveCurve with file: " + fileCurveFull);
+			return "";
+		}
 
 		return fileCurve;
 	}
